@@ -37,6 +37,7 @@ from pyee import EventEmitter
 from pyee.asyncio import AsyncIOEventEmitter
 
 import playwright
+import playwright._impl._impl_to_api_mapping
 from playwright._impl._errors import TargetClosedError, rewrite_error
 from playwright._impl._greenlets import EventGreenlet
 from playwright._impl._helper import Error, ParsedMessagePayload, parse_error
@@ -54,15 +55,18 @@ class Channel(AsyncIOEventEmitter):
         self._guid = object._guid
         self._object = object
         self.on("error", lambda exc: self._connection._on_event_listener_error(exc))
+        self._is_internal_type = False
 
     async def send(self, method: str, params: Dict = None) -> Any:
         return await self._connection.wrap_api_call(
-            lambda: self.inner_send(method, params, False)
+            lambda: self._inner_send(method, params, False),
+            self._is_internal_type,
         )
 
     async def send_return_as_dict(self, method: str, params: Dict = None) -> Any:
         return await self._connection.wrap_api_call(
-            lambda: self.inner_send(method, params, True)
+            lambda: self._inner_send(method, params, True),
+            self._is_internal_type,
         )
 
     def send_no_reply(self, method: str, params: Dict = None) -> None:
@@ -73,7 +77,7 @@ class Channel(AsyncIOEventEmitter):
             )
         )
 
-    async def inner_send(
+    async def _inner_send(
         self, method: str, params: Optional[Dict], return_as_dict: bool
     ) -> Any:
         if params is None:
@@ -108,6 +112,9 @@ class Channel(AsyncIOEventEmitter):
         key = next(iter(result))
         return result[key]
 
+    def mark_as_internal_type(self) -> None:
+        self._is_internal_type = True
+
 
 class ChannelOwner(AsyncIOEventEmitter):
     def __init__(
@@ -132,7 +139,6 @@ class ChannelOwner(AsyncIOEventEmitter):
         self._channel: Channel = Channel(self._connection, self)
         self._initializer = initializer
         self._was_collected = False
-        self._is_internal_type = False
 
         self._connection._objects[guid] = self
         if self._parent:
@@ -157,9 +163,6 @@ class ChannelOwner(AsyncIOEventEmitter):
         self._objects[child._guid] = child
         child._parent = self
 
-    def mark_as_internal_type(self) -> None:
-        self._is_internal_type = True
-
     def _set_event_to_subscription_mapping(self, mapping: Dict[str, str]) -> None:
         self._event_to_subscription_mapping = mapping
 
@@ -359,7 +362,12 @@ class Connection(EventEmitter):
             "params": self._replace_channels_with_guids(params),
             "metadata": metadata,
         }
-        if self._tracing_count > 0 and frames and not object._is_internal_type:
+        if (
+            self._tracing_count > 0
+            and frames
+            and frames
+            and object._guid != "localUtils"
+        ):
             self.local_utils.add_stack_to_tracing_no_reply(id, frames)
 
         self._transport.send(message)
@@ -566,6 +574,12 @@ def _extract_stack_trace_information_from_stack(
     api_name = ""
     parsed_frames: List[StackFrame] = []
     for frame in st:
+        # Sync and Async implementations can have event handlers. When these are sync, they
+        # get evaluated in the context of the event loop, so they contain the stack trace of when
+        # the message was received. _impl_to_api_mapping is glue between the user-code and internal
+        # code to translate impl classes to api classes. We want to ignore these frames.
+        if playwright._impl._impl_to_api_mapping.__file__ == frame.filename:
+            continue
         is_playwright_internal = frame.filename.startswith(playwright_module_path)
 
         method_name = ""
@@ -605,4 +619,4 @@ def format_call_log(log: Optional[List[str]]) -> str:
         return ""
     if len(list(filter(lambda x: x.strip(), log))) == 0:
         return ""
-    return "\nCall log:\n" + "\n  - ".join(log) + "\n"
+    return "\nCall log:\n" + "\n".join(log) + "\n"
