@@ -18,7 +18,6 @@ import pathlib
 import typing
 from pathlib import Path
 from typing import Any, Dict, List, Optional, Union, cast
-from urllib.parse import parse_qs
 
 import playwright._impl._network as network
 from playwright._impl._api_structures import (
@@ -74,6 +73,8 @@ class APIRequest:
         timeout: float = None,
         storageState: Union[StorageState, str, Path] = None,
         clientCertificates: List[ClientCertificate] = None,
+        failOnStatusCode: bool = None,
+        maxRedirects: int = None,
     ) -> "APIRequestContext":
         params = locals_to_params(locals())
         if "storageState" in params:
@@ -405,7 +406,8 @@ class APIRequestContext(ChannelOwner):
             "fetch",
             {
                 "url": url,
-                "params": params_to_protocol(params),
+                "params": object_to_array(params) if isinstance(params, dict) else None,
+                "encodedParams": params if isinstance(params, str) else None,
                 "method": method,
                 "headers": serialized_headers,
                 "postData": post_data,
@@ -422,31 +424,18 @@ class APIRequestContext(ChannelOwner):
         return APIResponse(self, response)
 
     async def storage_state(
-        self, path: Union[pathlib.Path, str] = None
+        self,
+        path: Union[pathlib.Path, str] = None,
+        indexedDB: bool = None,
     ) -> StorageState:
-        result = await self._channel.send_return_as_dict("storageState")
+        result = await self._channel.send_return_as_dict(
+            "storageState", {"indexedDB": indexedDB}
+        )
         if path:
             await async_writefile(path, json.dumps(result))
         return result
 
 
-def params_to_protocol(params: Optional[ParamsType]) -> Optional[List[NameValue]]:
-    if not params:
-        return None
-    if isinstance(params, dict):
-        return object_to_array(params)
-    if params.startswith("?"):
-        params = params[1:]
-    parsed = parse_qs(params)
-    if not parsed:
-        return None
-    out = []
-    for name, values in parsed.items():
-        for value in values:
-            out.append(NameValue(name=name, value=value))
-    return out
-
-
 def file_payload_to_json(payload: FilePayload) -> ServerFilePayload:
     return ServerFilePayload(
         name=payload["name"],
@@ -492,11 +481,14 @@ class APIResponse:
 
     async def body(self) -> bytes:
         try:
-            result = await self._request._channel.send_return_as_dict(
-                "fetchResponseBody",
-                {
-                    "fetchUid": self._fetch_uid,
-                },
+            result = await self._request._connection.wrap_api_call(
+                lambda: self._request._channel.send_return_as_dict(
+                    "fetchResponseBody",
+                    {
+                        "fetchUid": self._fetch_uid,
+                    },
+                ),
+                True,
             )
             if result is None:
                 raise Error("Response has been disposed")
